unit uOptionsUI;
{$INCLUDE 'Plugin.inc'}

interface

uses
  {$INCLUDE 'DelphiFarUnits.inc'} ,
  uOptions;

type
  TOptionsDialog = class(TOkCancelDialog)
  private
    fOptions: TOptions;
    fCheckTinyHelp: TFarDialog.TCheckbox;
    fCheckSelectRenamedFiles: TFarDialog.TCheckbox;
    fCheckDisableInternalHotkeys: TFarDialog.TCheckbox;
    fCheckSelectDestinationFilename: TFarDialog.TCheckbox;
    fCheckUpdateDescriptions: TFarDialog.TCheckbox;
    fLabelDescriptionFiles: TFarDialog.TLabel;
    fEditDescriptionFiles: TFarDialog.TEdit;
    fLabelCursorMovement: TFarDialog.TLabel;
    fComboCursorMovement: TFarDialog.TCombobox;
    fLabelSmartEndBehavior: TFarDialog.TLabel;
    fComboSmartEndBehavior: TFarDialog.TCombobox;
    function GetCursorMovementOption: TOptions.TCursorMovementOption;
    procedure SetCursorMovementOption(const Value: TOptions.TCursorMovementOption);
    function GetSmartEndBehaviorOption: TOptions.TSmartEndBehaviorOption;
    procedure SetSmartEndBehaviorOption(const Value: TOptions.TSmartEndBehaviorOption);
  protected
    procedure Clear; override;
    procedure CreateUserControls; override;
    procedure SetSize(Width, Height: integer); override;
    procedure ConsoleSizeToDialogSize(var Width, Height: Integer); override;
    property CheckTinyHelp: TFarDialog.TCheckbox read fCheckTinyHelp;
    property CheckSelectRenamedFiles: TFarDialog.TCheckbox read fCheckSelectRenamedFiles;
    property CheckDisableInternalHotkeys: TFarDialog.TCheckbox read fCheckDisableInternalHotkeys;
    property CheckSelectDestinationFilename: TFarDialog.TCheckbox read fCheckSelectDestinationFilename;
    property CheckUpdateDescriptions: TFarDialog.TCheckbox read fCheckUpdateDescriptions;
    property LabelDescriptionFiles: TFarDialog.TLabel read fLabelDescriptionFiles;
    property EditDescriptionFiles: TFarDialog.TEdit read fEditDescriptionFiles;
    property LabelCursorMovement: TFarDialog.TLabel read fLabelCursorMovement;
    property ComboCursorMovement: TFarDialog.TCombobox read fComboCursorMovement;
    property CursorMovementOption: TOptions.TCursorMovementOption read GetCursorMovementOption write SetCursorMovementOption;
    property LabelSmartEndBehavior: TFarDialog.TLabel read fLabelSmartEndBehavior;
    property ComboSmartEndBehavior: TFarDialog.TCombobox read fComboSmartEndBehavior;
    property SmartEndBehaviorOption: TOptions.TSmartEndBehaviorOption read GetSmartEndBehaviorOption write SetSmartEndBehaviorOption;
  public
    constructor Create;
    destructor Destroy; override;
    function Execute: boolean;
    property Options: TOptions read fOptions write fOptions;
  end;

implementation

uses
  uMessages,
  uPluginConsts;

{ TOptionsDialog }

procedure TOptionsDialog.Clear;
begin
  inherited;
  fCheckTinyHelp := nil;
  fCheckSelectRenamedFiles := nil;
  fCheckDisableInternalHotkeys := nil;
  fCheckSelectDestinationFilename := nil;
  fCheckUpdateDescriptions := nil;
  fLabelDescriptionFiles := nil;
  fEditDescriptionFiles := nil;
  fLabelCursorMovement := nil;
  fComboCursorMovement := nil;
  fLabelSmartEndBehavior := nil;
  fComboSmartEndBehavior := nil;
end;

constructor TOptionsDialog.Create;
begin
  inherited Create(DIALOG_OPTIONS_GUID);
end;

procedure TOptionsDialog.CreateUserControls;
begin
  inherited;
  fCheckTinyHelp := AddCheckbox(0, 0, GetMsg(MTinyHelpOption), False);
  fCheckSelectRenamedFiles := AddCheckbox(0, 0, GetMsg(MSelectRenamedFilesOption), False);
  fCheckDisableInternalHotkeys := AddCheckbox(0, 0, GetMsg(MDisableInternalHotkeysOption), False);
  fCheckSelectDestinationFilename := AddCheckbox(0, 0, GetMsg(MSelectDestinationFilenameOption), False);
  fCheckUpdateDescriptions := AddCheckbox(0, 0, GetMsg(MCheckUpdateDescriptionsOption), False);
  fLabelDescriptionFiles := AddLabel(0, 0, 0, GetMsg(MDescriptionFilesOption));
  fEditDescriptionFiles := AddEdit(0, 0, 0, '');
  fLabelCursorMovement := AddLabel(0, 0, 0, GetMsg(MCursorMovementOption));
  fComboCursorMovement := AddComboBox(0, 0, 0, '');
  fComboCursorMovement.Items.Add(GetMsg(MCursorMovementOption_MinimizeScrolling));
  fComboCursorMovement.Items.Add(GetMsg(MCursorMovementOption_PrioritizeSource));
  fComboCursorMovement.Items.Add(GetMsg(MCursorMovementOption_PrioritizeDestination));
  fComboCursorMovement.Items.Add(GetMsg(MCursorMovementOption_MaximumDestination));
  fComboCursorMovement.DropDownList := True;
  fLabelSmartEndBehavior := AddLabel(0, 0, 0, GetMsg(MSmartEndBehaviorOption));
  fComboSmartEndBehavior := AddComboBox(0, 0, 0, '');
  fComboSmartEndBehavior.Items.Add(GetMsg(MSmartEndBehaviorOption_ExtStartLineEnd));
  fComboSmartEndBehavior.Items.Add(GetMsg(MSmartEndBehaviorOption_ExtStartExtEnd));
  fComboSmartEndBehavior.Items.Add(GetMsg(MSmartEndBehaviorOption_ExtEndLineEnd));
  fComboSmartEndBehavior.DropDownList := True;
end;

destructor TOptionsDialog.Destroy;
begin
  inherited;
end;

function TOptionsDialog.Execute: boolean;
begin
  Result := False;
  CheckTinyHelp.Checked := Options.TinyHelp;
  CheckSelectRenamedFiles.Checked := Options.SelectRenamedFiles;
  CheckDisableInternalHotkeys.Checked := Options.DisableInternalHotkeys;
  CheckSelectDestinationFilename.Checked := Options.SelectDestinationFilename;
  CheckUpdateDescriptions.Checked := Options.UpdateDescriptions;
  CursorMovementOption := Options.CursorMovement;
  SmartEndBehaviorOption := Options.SmartEndBehavior;
  EditDescriptionFiles.Text := Options.DescriptionFiles;
  if inherited Execute then
  begin
    Options.TinyHelp := CheckTinyHelp.Checked;
    Options.SelectRenamedFiles := CheckSelectRenamedFiles.Checked;
    Options.DisableInternalHotkeys := CheckDisableInternalHotkeys.Checked;
    Options.SelectDestinationFilename := CheckSelectDestinationFilename.Checked;
    Options.UpdateDescriptions := CheckUpdateDescriptions.Checked;
    Options.CursorMovement := CursorMovementOption;
    Options.SmartEndBehavior := SmartEndBehaviorOption;
    Options.DescriptionFiles := EditDescriptionFiles.Text;
    Result := True;
  end;
end;

function TOptionsDialog.GetCursorMovementOption: TOptions.TCursorMovementOption;
begin
  case ComboCursorMovement.ItemIndex of
    0:   Result := cmoMinimizeScrolling;
    1:   Result := cmoPrioritizeSourceFileName;
    2:   Result := cmoPrioritizeDestinationFileName;
    3:   Result := cmoDestinationFileNameOnly;
    else Result := cmoMinimizeScrolling;
  end;
end;

function TOptionsDialog.GetSmartEndBehaviorOption: TOptions.TSmartEndBehaviorOption;
begin
  case ComboSmartEndBehavior.ItemIndex of
    0:   Result := sebExtStartLineEnd;
    1:   Result := sebExtStartExtEnd;
    2:   Result := sebExtEndLineEnd;
    else Result := sebExtStartLineEnd;
  end;
end;

procedure TOptionsDialog.SetCursorMovementOption(const Value: TOptions.TCursorMovementOption);
begin
  case Value of
    cmoMinimizeScrolling:
      ComboCursorMovement.ItemIndex := 0;
    cmoPrioritizeSourceFileName:
      ComboCursorMovement.ItemIndex := 1;
    cmoPrioritizeDestinationFileName:
      ComboCursorMovement.ItemIndex := 2;
    cmoDestinationFileNameOnly:
      ComboCursorMovement.ItemIndex := 3;
  end;
end;

procedure TOptionsDialog.SetSize(Width, Height: integer);
begin
  inherited;
  AutoPos(CheckTinyHelp);
  AutoPos(CheckSelectRenamedFiles);
  AutoPos(CheckDisableInternalHotkeys);
  AutoPos(CheckSelectDestinationFilename);
  AutoPos(CheckUpdateDescriptions);
  AutoPos(LabelDescriptionFiles, 4);
  AutoPosRight(EditDescriptionFiles, LabelDescriptionFiles);
  AutoPos(LabelCursorMovement);
  AutoPosRight(ComboCursorMovement, LabelCursorMovement);
  AutoPos(LabelSmartEndBehavior);
  AutoPosRight(ComboSmartEndBehavior, LabelSmartEndBehavior);
end;

procedure TOptionsDialog.SetSmartEndBehaviorOption(const Value: TOptions.TSmartEndBehaviorOption);
begin
  case Value of
    sebExtStartLineEnd:
      ComboSmartEndBehavior.ItemIndex := 0;
    sebExtStartExtEnd:
      ComboSmartEndBehavior.ItemIndex := 1;
    sebExtEndLineEnd:
      ComboSmartEndBehavior.ItemIndex := 2;
  end;
end;

procedure TOptionsDialog.ConsoleSizeToDialogSize(var Width, Height: Integer);
begin
  inherited;
  Height := 14;
end;

end.
